package org.rcisoft.business.bspace.controller;


/*固定导入*/
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import javax.validation.Valid;


import org.rcisoft.business.bspace.entity.BSpace;
import org.rcisoft.business.bspace.service.BSpaceService;

import java.util.List;

/**
* Created by cy on 2018-12-17 13:50:52.
*/
@RestController
@RequestMapping("/bspace")
public class BSpaceController extends CyPaginationController<BSpace> {

    @Autowired
    private BSpaceService bSpaceServiceImpl;


    @ApiOperation(value="添加", notes="添加")
    //@ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PostMapping(value = "/add")
    public CyResult add(@Valid BSpace bSpace, BindingResult bindingResult) {
        CyPersistModel data = bSpaceServiceImpl.save(bSpace);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        bSpace);
    }

    @ApiOperation(value="逻辑删除", notes="逻辑删除")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable String businessId,BSpace bSpace) {
        bSpace.setBusinessId(businessId);
        CyPersistModel data = bSpaceServiceImpl.removeLogical(bSpace);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="删除", notes="删除")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable String businessId,BSpace bSpace) {
        bSpace.setBusinessId(businessId);
        CyPersistModel data = bSpaceServiceImpl.remove(bSpace);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @ApiOperation(value="修改", notes="修改")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = false, dataType = "varchar")})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable String businessId, @Valid BSpace bSpace, BindingResult bindingResult) {
        bSpace.setBusinessId(businessId);
        CyPersistModel data = bSpaceServiceImpl.merge(bSpace);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        bSpace);
    }

    @ApiOperation(value="查询单一", notes="查询单一")
    @ApiImplicitParams({@ApiImplicitParam(name = "businessId", value = "businessId", required = true, dataType = "varchar")})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable String businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        bSpaceServiceImpl.findById(businessId));
    }

    @ApiOperation(value="查询集合", notes="查询集合")
    @GetMapping(value = "/queryBSpaces")
    public CyResult queryBSpaces(BSpace bSpace) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            bSpaceServiceImpl.findAll(bSpace));
    }

    @ApiOperation(value="分页查询集合", notes="分页查询集合")
    @GetMapping(value = "/queryBSpaceByPagination")
    public CyGridModel listByPagination(BSpace bSpace) {
        bSpaceServiceImpl.findAllByPagination(getPaginationUtility(), bSpace);
        return getGridModelResponse();
    }
}
