package org.rcisoft.business.bspace.service.impl;

import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.business.bspace.dao.BSpaceRepository;
import org.rcisoft.business.bspace.entity.BSpace;
import org.rcisoft.business.bspace.service.BSpaceService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;


import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2018-12-17 13:50:52.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class BSpaceServiceImpl extends CyBaseService  implements BSpaceService {

    private static final long serialVersionUID = -3485875433825192456L;
    @Autowired
    private BSpaceRepository bSpaceRepository;


    /**
    * 保存 
    * @param bSpace
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel save(BSpace bSpace){
        //增加操作
        CyUserUtil.setCurrentPersistOperation(bSpace);
        int line = bSpaceRepository.insertSelective(bSpace);
        this.dbInfo(CyUserUtil.getAuthenUsername() + "新增了ID为"+bSpace.getBusinessId()+"的信息","新增");
        log.info(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            bSpace.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 
    * @param bSpace
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(BSpace bSpace){
        int line = bSpaceRepository.deleteByPrimaryKey(bSpace.getBusinessId());
        this.dbInfo(CyUserUtil.getAuthenUsername()+"删除了ID为"+bSpace.getBusinessId()+"的信息","删除");
        log.info(CyUserUtil.getAuthenUsername()+"删除了ID为"+bSpace.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 
    * @param bSpace
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(BSpace bSpace){
        CyUserUtil.setCurrentMergeOperation(bSpace);
        bSpace.setDeleted();
        int line = bSpaceRepository.logicalDelete(bSpace);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+bSpace.getBusinessId()+"的信息","逻辑删除");
        log.info(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+bSpace.getBusinessId()+"的信息");

        return new CyPersistModel(line);
    }

    /**
    * 修改 
    * @param bSpace
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(BSpace bSpace){
        CyUserUtil.setCurrentMergeOperation(bSpace);
        int line = bSpaceRepository.updateByPrimaryKeySelective(bSpace);
        this.dbInfo(CyUserUtil.getAuthenUsername()+"修改了ID为"+bSpace.getBusinessId()+"的信息","修改");
        log.info(CyUserUtil.getAuthenUsername()+"修改了ID为"+bSpace.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 
    * @param id
    * @return
    */
    @Override
    public BSpace findById(String id){
        return bSpaceRepository.selectByPrimaryKey(id);
    }

    /**
    * 分页查询 
    * @param bSpace
    * @return
    */
    @Override
    public List<BSpace> findAllByPagination(CyPageUtil<BSpace> paginationUtility,
        BSpace bSpace){
        bSpace.setNormal();
        return bSpaceRepository.queryBSpaces(bSpace);
    }
    /**
    * 查询list 
    * @param bSpace
    * @return
    */
    @Override
    public List<BSpace> findAll(BSpace bSpace){
        bSpace.setNormal();
        return bSpaceRepository.queryBSpaces(bSpace);
    }

}
